aboutsummaryrefslogtreecommitdiff
path: root/image/codecs/indeo/vlc.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-09-10 21:05:49 -0400
committerPaul Gilbert2016-09-10 21:05:49 -0400
commit2f7da2d3d9a6c9ef998a8e1b91a4554e6d1b9d74 (patch)
treebf4f8e4473bc152f47ca2a0afb13efcacb786075 /image/codecs/indeo/vlc.h
parent23b1dbbb0e9c10035a1df98bffa9d6eaa5a6d338 (diff)
downloadscummvm-rg350-2f7da2d3d9a6c9ef998a8e1b91a4554e6d1b9d74.tar.gz
scummvm-rg350-2f7da2d3d9a6c9ef998a8e1b91a4554e6d1b9d74.tar.bz2
scummvm-rg350-2f7da2d3d9a6c9ef998a8e1b91a4554e6d1b9d74.zip
IMAGE: Miscellaneous cleanup for Indeo decompressors
Diffstat (limited to 'image/codecs/indeo/vlc.h')
-rw-r--r--image/codecs/indeo/vlc.h45
1 files changed, 16 insertions, 29 deletions
diff --git a/image/codecs/indeo/vlc.h b/image/codecs/indeo/vlc.h
index 01c7b1160b..51e887d3ae 100644
--- a/image/codecs/indeo/vlc.h
+++ b/image/codecs/indeo/vlc.h
@@ -56,7 +56,7 @@ struct VLCcode {
struct VLC {
private:
- static int compare_vlcspec(const void *a, const void *b);
+ static int compareVlcSpec(const void *a, const void *b);
/**
* Gets a value of a given size from a table
@@ -69,17 +69,17 @@ private:
public:
int _bits;
VLC_TYPE (*_table)[2]; ///< code, bits
- int _table_size, _table_allocated;
+ int _tableSize, _tableAllocated;
VLC();
/* Build VLC decoding tables suitable for use with get_vlc().
- 'nb_bits' sets the decoding table size (2^nb_bits) entries. The
+ 'nbBits' sets the decoding table size (2^nbBits) entries. The
bigger it is, the faster is the decoding. But it should not be too
big to save memory and L1 cache. '9' is a good compromise.
- 'nb_codes' : number of vlcs codes
+ 'nbCodes' : number of vlcs codes
'bits' : table which gives the size (in bits) of each vlc code.
@@ -96,52 +96,39 @@ public:
'wrap' and 'size' make it possible to use any memory configuration and types
(byte/word/long) to store the 'bits', 'codes', and 'symbols' tables.
- 'use_static' should be set to 1 for tables, which should be freed
- with av_free_static(), 0 if ff_free_vlc() will be used.
+ 'useStatic' should be set to 1 for tables, which should be freed
+ with av_free_static(), 0 if freeVlc() will be used.
*/
- int init_vlc(int nb_bits, int nb_codes, const void *bits, int bits_wrap,
- int bits_size, const void *codes, int codes_wrap, int codes_size,
- const void *symbols, int symbols_wrap, int symbols_size, int flags);
+ int init_vlc(int nbBits, int nbCodes, const void *bits, int bitsWrap,
+ int bitsSize, const void *codes, int codesWrap, int codesSize,
+ const void *symbols, int symbolsWrap, int symbolsSize, int flags);
- int init_vlc(int nb_bits, int nb_codes, const void *bits, int bits_wrap, int bits_size,
- const void *codes, int codes_wrap, int codes_size, int flags);
+ int init_vlc(int nbBits, int nbCodes, const void *bits, int bitsWrap, int bitsSize,
+ const void *codes, int codesWrap, int codesSize, int flags);
/**
* Free VLC data
*/
- void ff_free_vlc();
+ void freeVlc();
/**
* Build VLC decoding tables suitable for use with get_vlc().
*
* @param table_nb_bits max length of vlc codes to store directly in this table
* (Longer codes are delegated to subtables.)
*
* @param nb_codes number of elements in codes[]
*
* @param codes descriptions of the vlc codes
* These must be ordered such that codes going into the same subtable are contiguous.
* Sorting by VLCcode.code is sufficient, though not necessary.
*/
- int build_table(int table_nb_bits, int nb_codes,
- VLCcode *codes, int flags);
+ int buildTable(int tableNbBits, int nbCodes, VLCcode *codes, int flags);
- int alloc_table(int size, int use_static);
+ int allocTable(int size, int useStatic);
};
-
-/**
- * Reverse "nbits" bits of the value "val" and return the result
- * in the least significant bits.
- */
-extern uint16 inv_bits(uint16 val, int nbits);
-
-/**
- * Swap the order of the bytes in the passed value
- */
-extern uint32 bitswap_32(uint32 x);
-
} // End of namespace Indeo
} // End of namespace Image
@@ -96,52 +96,39 @@ public:
* Build VLC decoding tables suitable for use with get_vlc().
*
- * @param table_nb_bits max length of vlc codes to store directly in this table
+ * @param tableNbBits max length of vlc codes to store directly in this table
* (Longer codes are delegated to subtables.)
*
@@ -96,52 +96,39 @@ public:
* (Longer codes are delegated to subtables.)
*
- * @param nb_codes number of elements in codes[]
+ * @param nbCodes number of elements in codes[]
*
* @param codes descriptions of the vlc codes